package RTEMS::Mock::Config;

use strict;
use vars qw(@ISA @EXPORT);

@ISA = qw(Exporter);   
@EXPORT = qw(%distrorecs distrodirs builddirs @rtems_versions &rtemsversionbyrpmname);

use vars qw(%distrorecs @rtems_versions);

my @distros_infra = (
  { id => "fedora 20",
    scut => "fc20", 
    name => "fedora",
    version => "20",
    suffix => ".fc20",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "fedora 19",
    scut => "fc19", 
    name => "fedora",
    version => "19",
    suffix => ".fc19",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "rhel 6",
    scut => "el6", 
    name => "centos",
    version => "6",
    suffix => ".el6",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "rhel 5",
    scut => "el5", 
    name => "centos",
    version => "5",
    suffix => ".el5",
    archs => [ "i386", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 13.1",
    scut => "suse13_1", 
    name => "suse",
    version => "13.1",
    suffix => ".suse13.1",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 12.3",
    scut => "suse12_3", 
    name => "suse",
    version => "12.3",
    suffix => ".suse12.3",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 12.2",
    scut => "suse12_2", 
    name => "suse",
    version => "12.2",
    suffix => ".suse12.2",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
);

my @distros_4_11 = (
  { id => "fedora 20",
    scut => "fc20", 
    name => "fedora",
    version => "20",
    suffix => ".fc20",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "fedora 19",
    scut => "fc19", 
    name => "fedora",
    version => "19",
    suffix => ".fc19",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "rhel 6",
    scut => "el6", 
    name => "centos",
    version => "6",
    suffix => ".el6",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "rhel 5",
    scut => "el5", 
    name => "centos",
    version => "5",
    suffix => ".el5",
    archs => [ "i386", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 13.1",
    scut => "suse13_1", 
    name => "suse",
    version => "13.1",
    suffix => ".suse13.1",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 12.3",
    scut => "suse12_3", 
    name => "suse",
    version => "12.3",
    suffix => ".suse12.3",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 12.2",
    scut => "suse12_2", 
    name => "suse",
    version => "12.2",
    suffix => ".suse12.2",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "cygwin 1",
    scut => "cygwin", 
    name => "cygwin",
    version => undef,
    suffix => ".cyg",
    archs => [ "i686" ],
    srpmargs => "" 
  },
  { id => "mingw64 1",
    scut => "mingw64", 
    name => "mingw64",
    version => undef,
    suffix => ".mgw",
    archs => [ "i686", "x86_64" ],
    srpmargs => "" 
  }
);

my @distros_4_10 = (
  { id => "fedora 20",
    scut => "fc20", 
    name => "fedora",
    version => "20",
    suffix => ".fc20",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "fedora 19",
    scut => "fc19", 
    name => "fedora",
    version => "19",
    suffix => ".fc19",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "rhel 6",
    scut => "el6", 
    name => "centos",
    version => "6",
    suffix => ".el6",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "rhel 5",
    scut => "el5", 
    name => "centos",
    version => "5",
    suffix => ".el5",
    archs => [ "i386", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 13.1",
    scut => "suse13_1", 
    name => "suse",
    version => "13.1",
    suffix => ".suse13.1",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 12.3",
    scut => "suse12_3", 
    name => "suse",
    version => "12.3",
    suffix => ".suse12.3",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "suse 12.2",
    scut => "suse12_2", 
    name => "suse",
    version => "12.2",
    suffix => ".suse12.2",
    archs => [ "i586", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "cygwin 1",
    scut => "cygwin", 
    name => "cygwin",
    version => undef,
    suffix => ".cyg",
    archs => [ "i686" ],
    srpmargs => "" 
  },
  { id => "mingw32 1",
    scut => "mingw32", 
    name => "mingw32",
    version => undef,
    suffix => ".mgw",
    archs => [ "i686" ],
    srpmargs => "" 
  }
);

my @distros_4_9 = (
  { id => "rhel 6",
    scut => "el6", 
    name => "centos",
    version => "6",
    suffix => ".el6",
    archs => [ "i386", "x86_64" ],
    srpmargs => "" 
  },
  { id => "rhel 5",
    scut => "el5", 
    name => "centos",
    version => "5",
    suffix => ".el5",
    archs => [ "i386", "x86_64" ],
    srpmargs => "--define \"_source_filedigest_algorithm md5\" --define \"_binary_filedigest_algorithm md5\"" 
  },
  { id => "cygwin 1",
    scut => "cygwin", 
    name => "cygwin",
    version => undef,
    suffix => ".cyg",
    archs => [ "i686" ],
    srpmargs => "" 
  },
  { id => "mingw32 1",
    scut => "mingw32", 
    name => "mingw32",
    version => undef,
    suffix => ".mgw",
    archs => [ "i686" ],
    srpmargs => "" 
  }
);

@rtems_versions = (
 { prefix => "rtems-4.11-",
   id => "rtems4.11",
   vers => "4.11",
   distros => \@distros_4_11
 },
 { prefix => "rtems-4.10-",
   id => "rtems4.10",
   vers => "4.10",
   distros => \@distros_4_10
 },
 { prefix => "rtems-4.9-",
   id => "rtems4.9",
   vers => "4.9",
   distros => \@distros_4_9
 },
 { prefix => "",
   id => "rtems-infra",
   vers => "infrastructure",
   distros => \@distros_infra
 },
);

sub distrodirs()
{
  my @ids = ();
  foreach my $i ( @rtems_versions ) {
    foreach my $distro (@{$i->{distros}}) {
      push @ids, $i->{vers} . '/' . $distro->{name}
          . ( defined($distro->{version}) ? '/' . $distro->{version} : '' )
          . '/' . 'SRPMS';
      foreach my $arch ( @{$distro->{archs}} ) {
        push @ids, $i->{vers} . '/' . $distro->{name}
          . ( defined($distro->{version}) ? '/' . $distro->{version} : '' )
          . '/' . $arch;
      }
    }
  }
  return @ids;
}

sub builddirs()
{
  my @ids = ();
  foreach my $i ( @rtems_versions ) {
    foreach my $distro (@{$i->{distros}}) {
      push @ids, $i->{vers} . '/' . $distro->{name}
        . ( defined($distro->{version}) ? '/' . $distro->{version} : ''  )
        . '/' . 'noarch';
      foreach my $arch ( @{$distro->{archs}} ) {
        push @ids, $i->{vers} . '/' . $distro->{name} 
          . ( defined($distro->{version}) ? '/' . $distro->{version} : '' )
          . '/' . $arch;
      }
    }
  }
  return @ids;
}

sub rtemsversionbyrpmname($)
{
  my $name =$_[0];
  my $result = undef;
  
  foreach my $i ( @rtems_versions ) {
    if ( $name =~ qr/$i->{prefix}.*$/ ) {
      $result = $i;
      last;
    }
  }
  return $result;
}

%distrorecs = ();

INIT
{
  foreach my $rvers ( @rtems_versions ) {
    foreach my $distro ( @{$rvers->{distros}} ) {
      foreach my $arch ( @{$distro->{archs}} ) {
        my $distid = $distro->{name}
          . ( defined($distro->{version}) ? '-' . $distro->{version} : '' )
          . '-' . $arch . '-' . $rvers->{id};

        my $osdir = undef;
        if ( $distro->{name} eq "cygwin" ) {
          $osdir = "cygwin"
          . '/' . ${rvers}->{vers}
          . '/' . '.rpms';
        } elsif ( $distro->{name} eq "mingw32" ) {
          $osdir = "mingw32"
          . '/' . ${rvers}->{vers}
          . '/' . '.rpms';
        } elsif ( $distro->{name} eq "mingw64" ) {
          $osdir = "mingw64"
          . '/' . ${rvers}->{vers}
          . '/' . '.rpms';
        }
        else {
          $osdir = "linux"
          . '/' . ${rvers}->{vers}
          . '/' . ${distro}->{name}
          . ( defined(${distro}->{version}) ? '/' . ${distro}->{version} : '' );
        }

        ${distrorecs}{$distid} = {
           distro  => $distro,
           rtems   => $rvers,
           arch => $arch,
           osdir => $osdir,
           suffix => ${distro}->{suffix},
           srpmargs => ${distro}->{srpmargs},
           scut => ${distro}->{scut}
        }
      }
    }
  }

}


1;
